==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Izgled grafike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Obnašanje</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Dvoklik</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Dvoklik za urejanje besedila</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Dvoklik za urejanje šrafure</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Dvoklik na blokovno referenco odpre blok</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Desni dvojni klik za reset</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Izberi blokovne reference skupaj z atributi</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation>Desni klik</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Desni klik za odizbor entitet</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Desni klik na entiteto prikaže kontekstni meni</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Dvoklik za izbiro konture</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Blokovni izbor</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Območje kurzorja</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation>Območje kurzorja za lepljenje:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation>Območje kurzorja za izbor entitet:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Izgled grafike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Obnašanje</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Dvoklik</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Dvoklik za urejanje besedila</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Dvoklik za urejanje šrafure</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Dvoklik na blokovno referenco odpre blok</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Desni dvojni klik za reset</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Izberi blokovne reference skupaj z atributi</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Skrij atribute, ko so skrite blokovne reference</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>Označi entiteto znotraj območja</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>Desni klik</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Desni klik za odizbor entitet</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Desni klik na entiteto prikaže kontekstni meni</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Dvoklik za izbiro konture</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Blokovni izbor</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Območje kurzorja</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>Območje kurzorja za lepljenje:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>Območje kurzorja za izbor entitet:</translation>
    </message>
</context>
</TS>
